@@ -1,7 +1,7 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) 1998-2014 Xavier Roche and other contributors
+Copyright (C) 1998-2015 Xavier Roche and other contributors
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -290,7 +290,7 @@ int main(int argc, char *argv[]) {
   /* launch */
   ret = help_server(argv[1], defaultPort);
 
-  htsthread_wait();
+  htsthread_wait_n(background_threads - 1);
   hts_uninit();
 
 #ifdef _WIN32
