@@ -1,7 +1,7 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) 1998-2014 Xavier Roche and other contributors
+Copyright (C) 1998-2015 Xavier Roche and other contributors
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -887,7 +887,9 @@ static void print_backtrace(void) {
   }
 #else
   const char msg[] = "No stack trace available on this OS :(\n";
-  write(FD_ERR, msg, sizeof(msg) - 1);
+  if (write(FD_ERR, msg, sizeof(msg) - 1) != sizeof(msg) - 1) {
+    /* sorry GCC */
+  }
 #endif
 }
 
